import config from '@/config'
import storage from '@/utils/storage'
import constant from '@/utils/constant'
import {
	login,
	logout,
	getInfo
} from '@/api/login'
import {
	getToken,
	setToken,
	removeToken
} from '@/utils/auth'
import {
	getUserCompany
} from '../../api/company/company'

const baseUrl = config.baseUrl

const user = {
	state: {
		token: getToken(),
		name: storage.get(constant.name),
		avatar: storage.get(constant.avatar),
		// roles: storage.get(constant.roles),
		permissions: storage.get(constant.permissions),
		// 企业id
		companyId: storage.get(constant.companyId),
		// 企业名
		companyName: storage.get(constant.companyName),
		// 企业简称
		companyAbbreviation:storage.get(constant.companyAbbreviation),
		// 账号
		userName: storage.get(constant.userName),
		// mt_company
		//权限 角色标识(企业账号：mt_company；驾驶员账号：mt_driver)
		roles: storage.get(constant.roles),
		//权限名 
		rolesName:storage.get(constant.rolesName),
		//司机姓名
		nickName:storage.get(constant.nickName),
		//司机ID
		userId:storage.get(constant.userId),
	},

	mutations: {
        SET_USERID: (state, userId) => {
			state.userId = userId
			storage.set(constant.userId, userId)
		},		
		SET_NICKNAME: (state, nickName) => {
			state.nickName = nickName
			storage.set(constant.nickName, nickName)
		},
		SET_ROLESNAME: (state, rolesName) => {
			state.rolesName = rolesName
			storage.set(constant.rolesName, rolesName)
		},
		SET_USERNAME: (state, userName) => {
			state.userName = userName
			storage.set(constant.userName, userName)
		},
		SET_COMPANYABBREVIATION: (state, companyAbbreviation) => {
			state.companyAbbreviation = companyAbbreviation
			storage.set(constant.companyAbbreviation, companyAbbreviation)
		},
		SET_COMPANYID: (state, companyId) => {
			state.companyId = companyId
			storage.set(constant.companyId, companyId)
		},
		SET_COMPANYNAME: (state, companyName) => {
			state.companyName = companyName
			storage.set(constant.companyName, companyName)
		},
		SET_TOKEN: (state, token) => {
			state.token = token
		},
		SET_NAME: (state, name) => {
			state.name = name
			storage.set(constant.name, name)
		},
		SET_AVATAR: (state, avatar) => {
			state.avatar = avatar
			storage.set(constant.avatar, avatar)
		},
		SET_ROLES: (state, roles) => {
			state.roles = roles
			storage.set(constant.roles, roles)
		},
		SET_PERMISSIONS: (state, permissions) => {
			state.permissions = permissions
			storage.set(constant.permissions, permissions)
		}
	},

	actions: {
		// 登录
		Login({
			commit
		}, userInfo) {
			const username = userInfo.username.trim()
			const password = userInfo.password
			const code = userInfo.code
			const uuid = userInfo.uuid
			return new Promise((resolve, reject) => {
				login(username, password, code, uuid).then(res => {
					setToken(res.data.access_token)
					commit('SET_TOKEN', res.data.access_token)
					resolve()
				}).catch(error => {
					reject(error)
				})
			})
		},

		// 获取用户信息
		GetInfo({
			commit,
			state
		}) {
			return new Promise((resolve, reject) => {
				getInfo().then(res => {
					console.log(res, 'res')
					// const user = res.user
					// const avatar = (user == null || user.avatar == "" || user.avatar == null) ? require("@/static/images/profile.jpg") : baseUrl + user.avatar
					// const username = (user == null || user.userName == "" || user.userName == null) ? "" : user.userName
					// if (res.roles && res.roles.length > 0) {
					//   commit('SET_ROLES', res.roles)
					//   commit('SET_PERMISSIONS', res.permissions)
					// } else {
					//   commit('SET_ROLES', ['ROLE_DEFAULT'])
					// }
					// commit('SET_NAME', username)
					// commit('SET_AVATAR', avatar)
					let name='城管';
					// 角色标识(企业账号：mt_company；驾驶员账号：mt_driver)
					if(res.data.user=='mt_company'){
						name='企业'
					}else if(res.data.user=='mt_driver'){
						name='司机'
					}
					
					commit('SET_ROLESNAME', name)
					commit('SET_USERID', res.data.userId)
					commit('SET_COMPANYID', res.data.companyId)
					commit('SET_COMPANYNAME', res.data.companyName)
					commit('SET_COMPANYABBREVIATION', res.data.companyAbbreviation)
					commit('SET_USERNAME', res.data.userName)
					commit('SET_NICKNAME', res.data.nickName)
					resolve(res)
				}).catch(error => {
					reject(error)
				})
			})
		},

		// 退出系统
		LogOut({
			commit,
			state
		}) {
			return new Promise((resolve, reject) => {
				logout(state.token).then(() => {
					commit('SET_TOKEN', '')
					commit('SET_ROLES', [])
					commit('SET_PERMISSIONS', [])
					removeToken()
					storage.clean()
					resolve()
				}).catch(error => {
					reject(error)
				})
			})
		}
	}
}

export default user
